#!/bin/sh
#*******************************************************************************
#Licensed Materials - Property of IBM
#(c) Copyright IBM Corporation 2006-2009. All Rights Reserved.
#
#Note to U.S. Government Users Restricted Rights:  
#Use, duplication or disclosure restricted by GSA ADP Schedule 
#Contract with IBM Corp. 
#*******************************************************************************
# Jazz RepoTools Launcher

if [ `uname` = SunOS ];
  then
    SPACE_PATTERN=' ' ;
    VMARGS="$VMARGS -d64 -XX:MaxPermSize=256m" ;
    DEFINE="$DEFINE -Djava.protocol.handler.pkgs=com.ibm.net.ssl.www2.protocol" ;
  else
    SPACE_PATTERN='[[:space:]]' ;
    VMARGS="$VMARGS -Xjit:exclude={org.apache.xerces.parsers.AbstractSAXParser.*}" ;
fi

pwd | grep "$SPACE_PATTERN"
if [ $? -eq 0 ];
  then /bin/echo \
ERROR:  The Jazz Team Server may not be installed in a directory whose name contains a space character.  Please relocate the jazz directory and try again.
  exit 1
fi

START_DIR=`dirname "$0"`
FQ_START_DIR=`pwd`

if [ -z "$JAZZ_PROVISION_PROFILES" ] ; then
  JAZZ_PROVISION_PROFILES=$START_DIR/conf/jazz/provision_profiles ;
fi

if [ ! -d $JAZZ_PROVISION_PROFILES ] ;
  then /bin/echo \
ERROR:  Could not find configuration directory $JAZZ_PROVISION_PROFILES.  If you have moved or renamed your configuration directory, you can use the environment variable JAZZ_PROVISION_PROFILES to point to its new location.
  exit 1
fi

# The following four environment variables (*_ABSPATH) are used to point to a
# directory that contains the appropriate JDBC jar file supplied by the database
# vendor.  Users may set these variables; if they are set, the script will
# respect their value.  If they are unset, we look in a directory under
# <JazzInstallDir>/server by default.  (For example, the default location for
# the Oracle JDBC driver is under <JazzInstallDir>/server/oracle).

if [ -z "$ORACLE_ABSPATH" ] ; then
  ORACLE_ABSPATH="`cd \"$START_DIR\" 2>/dev/null && pwd || echo \"$START_DIR\"`/oracle" ;
fi

if [ -z "$SQLSERVER_ABSPATH" ] ; then
  SQLSERVER_ABSPATH="`cd \"$START_DIR\" 2>/dev/null && pwd || echo \"$START_DIR\"`/sqlserver" ;
fi

if [ -z "$DB2I_ABSPATH" ] ; then
  DB2I_ABSPATH="`cd \"$START_DIR\" 2>/dev/null && pwd || echo \"$START_DIR\"`/db2i" ;
fi

if [ -z "$DB2Z_ABSPATH" ] ; then
  DB2Z_ABSPATH="`cd \"$START_DIR\" 2>/dev/null && pwd || echo \"$START_DIR\"`/db2z" ;
fi

#DEFINE="$DEFINE -Dcom.ibm.team.repotools.rcp.allowInvalidBundles=true"
DEFINE="$DEFINE -Dcom.ibm.team.repository.provision.profile=$JAZZ_PROVISION_PROFILES"
DEFINE="$DEFINE -Dorg.eclipse.emf.ecore.plugin.EcorePlugin.doNotLoadResourcesPlugin=true"
DEFINE="$DEFINE -Djava.awt.headless=true"
DEFINE="$DEFINE -DORACLE_JDBC=$ORACLE_ABSPATH"
DEFINE="$DEFINE -DSQLSERVER_JDBC=$SQLSERVER_ABSPATH"
DEFINE="$DEFINE -DDB2I_JDBC=$DB2I_ABSPATH"
DEFINE="$DEFINE -DDB2Z_JDBC=$DB2Z_ABSPATH"
DEFINE="$DEFINE -DJAZZ_HOME=file://$FQ_START_DIR/conf"

VMARGS="$VMARGS -Xmx1500M"
#VMARGS="$VMARGS-Xdbg:suspend=y,server=y"

JAVA="$START_DIR/jre/bin/java"
LAUNCHER=org.eclipse.equinox.launcher_1.0.101.R34x_v20081125.jar         
JAR="$START_DIR/../repotools/eclipse/plugins/$LAUNCHER"
APPLICATION=com.ibm.team.repotools.rcp.repotools_application
    
$JAVA $VMARGS $DEFINE -jar $JAR -application $APPLICATION "$@" 
